'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _constants = require('./constants');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

exports.default = new Proxy(function () {}, {
    apply: function apply(a, b, args) {
        if (!args[0] || !args[0].raw) {
            return find.apply(undefined, _toConsumableArray(args));
        }
        return find(String.raw.apply(String, _toConsumableArray(args)));
    },
    get: function get(target, name) {
        return find(name);
    }
});


var isNumeric = function isNumeric(token) {
    return !isNaN(token);
};
var isNumber = function isNumber(token) {
    return _constants.numbers[token] !== undefined;
};
var isMultiplier = function isMultiplier(token) {
    return _constants.multipliers[token] !== undefined;
};
var isUnit = function isUnit(token) {
    return _constants.units[token] !== undefined;
};

function parse(token) {
    if (isNumeric(token)) {
        return { type: 'number', value: Number(token) };
    }
    if (isNumber(token)) {
        return { type: 'number', value: _constants.numbers[token] };
    }
    if (isMultiplier(token)) {
        return { type: 'multiplier', value: _constants.multipliers[token] };
    }
    if (isUnit(token)) {
        return { type: 'unit', value: _constants.units[token] };
    }
    throw new Error('Could not parse expression ' + token + '.');
}

function find(name) {
    if (!name) {
        return 0;
    }

    var isFuture = name.startsWith('IN');
    var isPast = name.endsWith('AGO');

    var terms = name.split(/[_\s\-]+/).map(function (term) {
        return term.toUpperCase();
    }).filter(function (term) {
        return !['IN', 'AGO', 'AND', 'OF'].includes(term);
    }).map(parse);

    var sum = 0;
    var partSum = 0;

    for (var i = 0; i < terms.length; i++) {
        var term = terms[i];

        switch (term.type) {
            case 'number':
                {
                    partSum += term.value;
                    break;
                }
            case 'multiplier':
                {
                    partSum = (partSum || 1) * term.value;
                    break;
                }
            case 'unit':
                {
                    sum = sum + partSum * term.value;
                    partSum = 0;
                    break;
                }
        }
    }

    sum += partSum;

    if (isFuture) {
        return Date.now() + sum;
    } else if (isPast) {
        return Date.now() - sum;
    }
    return sum;
}