"use strict";

var _templateObject = _taggedTemplateLiteral(["one_second"], ["one_second"]),
    _templateObject2 = _taggedTemplateLiteral(["ONE_WEEK"], ["ONE_WEEK"]),
    _templateObject3 = _taggedTemplateLiteral(["one second"], ["one second"]),
    _templateObject4 = _taggedTemplateLiteral(["ONE WEEK"], ["ONE WEEK"]),
    _templateObject5 = _taggedTemplateLiteral(["one-second"], ["one-second"]),
    _templateObject6 = _taggedTemplateLiteral(["ONE-WEEK"], ["ONE-WEEK"]),
    _templateObject7 = _taggedTemplateLiteral(["ONE-WEEK_AND seven minutes"], ["ONE-WEEK_AND seven minutes"]),
    _templateObject8 = _taggedTemplateLiteral(["1 day ", " minutes and ", " seconds"], ["1 day ", " minutes and ", " seconds"]),
    _templateObject9 = _taggedTemplateLiteral(["a minute 60 seconds"], ["a minute 60 seconds"]),
    _templateObject10 = _taggedTemplateLiteral(["1 minute 60 seconds"], ["1 minute 60 seconds"]),
    _templateObject11 = _taggedTemplateLiteral(["1 minute .5 seconds"], ["1 minute .5 seconds"]);

var _ = require(".");

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

var MILLISECOND = 1;
var SECOND = 1000 * MILLISECOND;
var MINUTE = 60 * SECOND;
var HOUR = 60 * MINUTE;
var DAY = 24 * HOUR;
var WEEK = 7 * DAY;
var MONTH = 30 * DAY;
var YEAR = 365 * DAY;
var DECADE = 10 * YEAR;

describe("properties without units", function () {
  it("returns correct with just numbers", function () {
    expect(_2.default.ZERO).toBe(0);
    expect(_2.default.ONE).toBe(1);
    expect(_2.default.NINE).toBe(9);
    expect(_2.default.THIRTEEN).toBe(13);
  });

  it("throws an error if number is unparseable", function () {
    expect(function () {
      return _2.default.SOME_UNKNOWN_VARIABLE;
    }).toThrow(/Could not parse expression/);
  });
});

describe("properties with units", function () {
  it("returns correct with milliseconds", function () {
    expect(_2.default.ONE_MILLISECOND).toBe(1 * MILLISECOND);
    expect(_2.default.NINE_HUNDRED_MILLISECONDS).toBe(900 * MILLISECOND);
    expect(_2.default.NINETY_THOUSAND_MILLISECONDS).toBe(90000 * MILLISECOND);
  });

  it("returns correct with seconds", function () {
    expect(_2.default.TWO_SECONDS).toBe(2 * SECOND);
    expect(_2.default.THIRTY_SECONDS).toBe(30 * SECOND);
    expect(_2.default.HUNDRED_SECONDS).toBe(100 * SECOND);
  });

  it("returns correct with minutes", function () {
    expect(_2.default.THREE_MINUTES).toBe(3 * MINUTE);
    expect(_2.default.FIFTEEN_MINUTES).toBe(15 * MINUTE);
    expect(_2.default.HUNDRED_MINUTES).toBe(100 * MINUTE);
  });

  it("returns correct with hours", function () {
    expect(_2.default.ONE_HOURS).toBe(1 * HOUR);
    expect(_2.default.FOUR_HOURS).toBe(4 * HOUR);
    expect(_2.default.FOURTY_HOURS).toBe(40 * HOUR);
  });

  it("returns correct with days", function () {
    expect(_2.default.SEVEN_DAYS).toBe(7 * DAY);
    expect(_2.default.SEVENTEEN_DAYS).toBe(17 * DAY);
    expect(_2.default.EIGHTY_DAYS).toBe(80 * DAY);
  });

  it("returns correct with weeks", function () {
    expect(_2.default.FIVE_WEEKS).toBe(5 * WEEK);
    expect(_2.default.FIFTEEN_WEEKS).toBe(15 * WEEK);
    expect(_2.default.FIFTY_WEEKS).toBe(50 * WEEK);
  });

  it("returns correct with months", function () {
    expect(_2.default.ONE_MONTH).toBe(1 * MONTH);
    expect(_2.default.FIFTEEN_MONTHS).toBe(15 * MONTH);
    expect(_2.default.FIFTY_MONTHS).toBe(50 * MONTH);
  });

  it("returns correct with years", function () {
    expect(_2.default.ONE_YEAR).toBe(1 * YEAR);
    expect(_2.default.FIFTEEN_YEARS).toBe(15 * YEAR);
    expect(_2.default.FIFTY_YEARS).toBe(50 * YEAR);
  });

  it("returns correct with decades", function () {
    expect(_2.default.ONE_DECADE).toBe(1 * DECADE);
    expect(_2.default.FIFTEEN_DECADES).toBe(15 * DECADE);
    expect(_2.default.FIFTY_DECADES).toBe(50 * DECADE);
  });
});

describe("properties with combined numbers", function () {
  it("works with two numbers", function () {
    expect(_2.default.TWENTY_FIVE_SECONDS).toBe(25 * SECOND);
  });

  it("works with several numbers", function () {
    expect(_2.default.TWO_HUNDRED_TWENTY_FIVE_SECONDS).toBe(225 * SECOND);
  });

  it("ignores the AND term", function () {
    expect(_2.default.HUNDRED_AND_THIRTY_TWO).toBe(132);
    expect(_2.default.HUNDRED_AND_THIRTY_TWO_SECONDS).toBe(132 * SECOND);
  });
});

describe("properties with combined units", function () {
  it("works with two units", function () {
    expect(_2.default.TWO_MINUTES_AND_THREE_SECONDS).toBe(2 * MINUTE + 3 * SECOND);
    expect(_2.default.NINETY_HOURS_FOUR).toBe(90 * HOUR + 4);
  });

  it("works witn several units", function () {
    expect(_2.default.ONE_HOURS_TWO_MINUTES_THREE_SECONDS).toBe(HOUR + 2 * MINUTE + 3 * SECOND);
    expect(_2.default.NINE_WEEKS_TWELVE_DAYS_SEVEN_MINUTES_AND_HALF_A_SECOND).toBe(WEEK * 9 + DAY * 12 + MINUTE * 7 + 500);
  });
});

describe("properties with single unit", function () {
  it("works with single unit", function () {
    expect(_2.default.ONE_SECOND).toBe(SECOND);
    expect(_2.default.ONE_MINUTE).toBe(MINUTE);
    expect(_2.default.ONE_HOUR).toBe(HOUR);
    expect(_2.default.ONE_DAY).toBe(DAY);
    expect(_2.default.ONE_WEEK).toBe(WEEK);
    expect(_2.default.ONE_MONTH).toBe(MONTH);
    expect(_2.default.ONE_YEAR).toBe(YEAR);
    expect(_2.default.ONE_DECADE).toBe(DECADE);
  });
});

describe("properties with fraction units", function () {
  it("works with halves", function () {
    expect(_2.default.ONE_HALF_SECOND).toBe(500);
    expect(_2.default.HALF_A_SECOND).toBe(500);
    expect(_2.default.THREE_HALVES).toBe(1.5);
  });
  it("works with thirds", function () {
    expect(_2.default.A_THIRD_DAY).toBe(HOUR * 8);
    expect(_2.default.A_THIRD).toBe(1 / 3);
  });
  it("works with quarters", function () {
    expect(_2.default.THREE_QUARTERS_HOUR).toBe(HOUR / 4 * 3);
    expect(_2.default.A_QUARTER_DAY).toBe(HOUR * 6);
  });
});

describe("properties with a and an", function () {
  it("counts for one", function () {
    expect(_2.default.A_SECOND).toBe(SECOND);
    expect(_2.default.AN_HOUR).toBe(HOUR);
  });
  it("doesnt judge you for not knowing grammer", function () {
    expect(_2.default.AN_SECOND).toBe(SECOND);
    expect(_2.default.A_HOUR).toBe(HOUR);
  });
  it("see what I did there?", function () {});
});

describe("properties with of", function () {
  it("reads better, but doesn't cause trouble", function () {
    expect(_2.default.HALF_OF_A_MINUTE).toBe(MINUTE / 2);
    expect(_2.default.THIRTY_OF_SECONDS).toBe(SECOND * 30);
    expect(_2.default.A_QUARTER_OF_AN_HOUR).toBe(MINUTE * 15);
  });
});

describe("properties that are relative in time", function () {
  it("works with past", function () {
    var now = Date.now();
    Date.now = jest.fn(function () {
      return now;
    });

    expect(_2.default.AN_HOUR_AGO).toBe(now - HOUR);
    expect(_2.default.A_MINUTE_THIRTY_SECONDS_AGO).toBe(now - (MINUTE + 30 * SECOND));
  });
  it("works with future", function () {
    var now = Date.now();
    Date.now = jest.fn(function () {
      return now;
    });

    expect(_2.default.IN_AN_HOUR).toBe(now + HOUR);
    expect(_2.default.IN_A_WEEK_AND_SIX_DAYS).toBe(now + WEEK + DAY * 6);
  });
});

describe("edge cases", function () {
  it("works with any casing", function () {
    expect(_2.default.one_second).toBe(SECOND);
    expect(_2.default.one_Week).toBe(WEEK);
    expect(_2.default.ONE_hour).toBe(HOUR);
    expect(_2.default.OnE_DaY).toBe(DAY);
  });

  it("works with several multipliers back to back", function () {
    expect(_2.default.HUNDRED_THOUSAND_SECONDS).toBe(100 * 1000 * SECOND);
  });
});

describe("tagged template literal", function () {
  it("works with underscores", function () {
    expect((0, _2.default)(_templateObject)).toBe(SECOND);
    expect((0, _2.default)(_templateObject2)).toBe(WEEK);
  });
  it("works with spaces", function () {
    expect((0, _2.default)(_templateObject3)).toBe(SECOND);
    expect((0, _2.default)(_templateObject4)).toBe(WEEK);
  });
  it("works with hyphens", function () {
    expect((0, _2.default)(_templateObject5)).toBe(SECOND);
    expect((0, _2.default)(_templateObject6)).toBe(WEEK);
  });
  it("works with a mix of approaches", function () {
    expect((0, _2.default)(_templateObject7)).toBe(WEEK + MINUTE * 7);
  });

  it("works with arguments", function () {
    expect((0, _2.default)(_templateObject8, 60, 30)).toBe(DAY + MINUTE * 60 + 30 * SECOND);
  });
});

describe("numerics", function () {
  it("works with proxies", function () {
    expect(_2.default.A_MINUTE_20_SECONDS).toBe(MINUTE + 20 * 1000);
  });
  it("works with tagged template literals", function () {
    expect((0, _2.default)(_templateObject9)).toBe(2 * MINUTE);
    expect((0, _2.default)(_templateObject10)).toBe(2 * MINUTE);
    expect((0, _2.default)(_templateObject11)).toBe(MINUTE + 500);
  });
});

describe("alternative usage", function () {
  it("works when being called as a function", function () {
    expect((0, _2.default)()).toBe(0);
    expect((0, _2.default)("a minute 45")).toBe(MINUTE + 45);
    expect((0, _2.default)("a minute " + 45)).toBe(MINUTE + 45);
  });
});